==> haskell-css-text-0.1.3.0-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-2Wt1GnJcWZt88I9REarofL
key: css-text-0.1.3.0-2Wt1GnJcWZt88I9REarofL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
abi: 5ae7d93dd84d31dd34f0a66c5e848fbe
exposed: True
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
import-dirs: /usr/lib/ghc-8.6.5/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-2Wt1GnJcWZt88I9REarofL
depends:
    attoparsec-0.13.2.3-G0AWAouFPeyAsmzjnpc0yX base-4.12.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-GjyyspTxklxH8o1kLaeFXy
key: css-text-0.1.3.0-GjyyspTxklxH8o1kLaeFXy
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
abi: a9432f15325269fafe552b79e67998ee
exposed: True
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
import-dirs: /usr/lib/ghc-8.6.5/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-GjyyspTxklxH8o1kLaeFXy
depends:
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
